@@ -9,6 +9,9 @@ __all__ = ['activation',
            'loss',
            'gradient',
            'optimizer',
-           'load']
+           'load',
+           'CNN',
+           'RNN',
+           'datasets']
 
 from phidnet import *
\ No newline at end of file
