@@ -3,18 +3,18 @@ import phidnet.network_data
 
 
 
-def weight(axis0, axis1, num):   # Make weights in neural network dictionary
+def weight(axis0, axis1, layer=1):   # Make weights in neural network dictionary
     mat = np.random.randn(axis0, axis1)
-    phidnet.network_data.weight[num] = mat
-    phidnet.network_data.deltaWeight[num] = None
+    phidnet.network_data.weight[layer] = mat
+    phidnet.network_data.deltaWeight[layer] = None
     return 0
 
 
 
-def bias(axis1, num):   # Make biases in neural network dictionary
+def bias(axis1, layer=1):   # Make biases in neural network dictionary
     mat = np.random.randn(1, axis1)
-    phidnet.network_data.bias[num] = mat
-    phidnet.network_data.deltaBias[num] = None
+    phidnet.network_data.bias[layer] = mat
+    phidnet.network_data.deltaBias[layer] = None
     return 0
 
 
@@ -31,8 +31,8 @@ def build_network(layer_num):   # Build neural network, make nodes and set numbe
 
 
 
-def activation_function(activation_f_list):   # Save in list
-    phidnet.network_data.active = activation_f_list
+def activation_function(f_list):   # Save in list
+    phidnet.network_data.active = f_list
     return 0
 
 
@@ -48,4 +48,4 @@ def input_data(inp):   # Set input data X
 def target_data(inp):   # Set output data T (Target)
     data = np.array(inp)
     phidnet.network_data.target = data
-    return 0
\ No newline at end of file
+    return 0
